FsError

Enum FsError 

pub enum FsError {
Show 36 variants Inspect { path: PathBuf, source: Error, }, Remove { path: PathBuf, source: Error, }, RemoveAndDefer { path: PathBuf, deferred_path: PathBuf, source: Error, }, CreateDirectory { path: PathBuf, source: Error, }, CreateExtractedFile { path: PathBuf, source: Error, }, CreateTempFile { path: PathBuf, source: Error, }, WriteTempFile { path: PathBuf, source: Error, }, SyncTempFile { path: PathBuf, source: Error, }, FinalizeFile { temp_path: PathBuf, final_path: PathBuf, source: Error, }, OpenZipArchive { zip_path: PathBuf, source: Box<dyn StdError + Send + Sync + 'static>, }, OpenArchive { archive_path: PathBuf, source: Box<dyn StdError + Send + Sync + 'static>, }, ReadZipEntry { path: PathBuf, source: Box<dyn StdError + Send + Sync + 'static>, }, ReadArchiveEntry { path: PathBuf, source: Box<dyn StdError + Send + Sync + 'static>, }, ReadEntry { path: PathBuf, source: Error, }, WriteEntry { path: PathBuf, source: Error, }, ReadDirectory { path: PathBuf, source: Error, }, ReadDirectoryEntry { path: PathBuf, source: Error, }, CopyFile { source_path: PathBuf, target_path: PathBuf, source: Error, }, InvalidZipEntryPath, InvalidArchiveEntryPath, SymlinkEntry { path: PathBuf, }, SuspiciousCompressionRatio { path: PathBuf, uncompressed_size: u64, compressed_size: u64, max_ratio: u64, }, QuotaExceeded { max_total_size: u64, current_total_size: u64, entry_size: u64, }, PathTooDeep { path: PathBuf, depth: usize, max_depth: usize, }, ArchiveBackendUnavailable { archive_kind: &'static str, }, ArchiveBackendFailed { archive_kind: &'static str, archive_path: PathBuf, backend_path: PathBuf, source: Box<dyn StdError + Send + Sync + 'static>, }, FileCountExceeded { max_file_count: usize, current_file_count: usize, }, ReparsePoint { path: PathBuf, }, PathNotDirectory { path: PathBuf, }, HardlinkedTarget { path: PathBuf, }, CopyAcrossVolumes { source_dir: PathBuf, target_dir: PathBuf, source: Box<dyn StdError + Send + Sync + 'static>, }, MoveIntoPlace { source_dir: PathBuf, target_dir: PathBuf, source: Error, }, MoveAside { target_dir: PathBuf, backup_dir: PathBuf, source: Error, }, RollbackFailed { action: &'static str, source_dir: PathBuf, target_dir: PathBuf, source: Box<dyn StdError + Send + Sync + 'static>, rollback_error: Box<dyn StdError + Send + Sync + 'static>, }, CopySymlink { source_path: PathBuf, }, UnsupportedEntry { source_path: PathBuf, },
}

Variants



Inspect

Fields

path: PathBuf
source: Error


Remove

Fields

path: PathBuf
source: Error


RemoveAndDefer

Raised when immediate deletion fails and the path cannot be renamed for deferred cleanup.

Fields

path: PathBuf
deferred_path: PathBuf
source: Error


CreateDirectory

Fields

path: PathBuf
source: Error


CreateExtractedFile

Fields

path: PathBuf
source: Error


CreateTempFile

Fields

path: PathBuf
source: Error


WriteTempFile

Fields

path: PathBuf
source: Error


SyncTempFile

Fields

path: PathBuf
source: Error


FinalizeFile

Fields

temp_path: PathBuf
final_path: PathBuf
source: Error


OpenZipArchive

Fields

zip_path: PathBuf
source: Box<dyn StdError + Send + Sync + 'static>


OpenArchive

Fields

archive_path: PathBuf
source: Box<dyn StdError + Send + Sync + 'static>


ReadZipEntry

Fields

path: PathBuf
source: Box<dyn StdError + Send + Sync + 'static>


ReadArchiveEntry

Fields

path: PathBuf
source: Box<dyn StdError + Send + Sync + 'static>


ReadEntry

Fields

path: PathBuf
source: Error


WriteEntry

Fields

path: PathBuf
source: Error


ReadDirectory

Fields

path: PathBuf
source: Error


ReadDirectoryEntry

Fields

path: PathBuf
source: Error


CopyFile

Fields

source_path: PathBuf
target_path: PathBuf
source: Error


InvalidZipEntryPath



InvalidArchiveEntryPath



SymlinkEntry

Fields

path: PathBuf


SuspiciousCompressionRatio

Fields

path: PathBuf
uncompressed_size: u64
compressed_size: u64
max_ratio: u64


QuotaExceeded

Fields

max_total_size: u64
current_total_size: u64
entry_size: u64


PathTooDeep

Fields

path: PathBuf
depth: usize
max_depth: usize


ArchiveBackendUnavailable

Fields

archive_kind: &'static str


ArchiveBackendFailed

Fields

archive_kind: &'static str
archive_path: PathBuf
backend_path: PathBuf
source: Box<dyn StdError + Send + Sync + 'static>


FileCountExceeded

Fields

max_file_count: usize
current_file_count: usize


ReparsePoint

Fields

path: PathBuf


PathNotDirectory

Fields

path: PathBuf


HardlinkedTarget

Fields

path: PathBuf


CopyAcrossVolumes

Fields

source_dir: PathBuf
target_dir: PathBuf
source: Box<dyn StdError + Send + Sync + 'static>


MoveIntoPlace

Fields

source_dir: PathBuf
target_dir: PathBuf
source: Error


MoveAside

Fields

target_dir: PathBuf
backup_dir: PathBuf
source: Error


RollbackFailed

Raised when staged replacement fails and restoring the backup also fails.

Fields

action: &'static str
source_dir: PathBuf
target_dir: PathBuf
source: Box<dyn StdError + Send + Sync + 'static>
rollback_error: Box<dyn StdError + Send + Sync + 'static>

Fields

source_path: PathBuf


UnsupportedEntry

Fields

source_path: PathBuf

Implementations

Source

impl FsError

pub(crate) fn inspect(path: &Path, source: Error) -> Self

pub(crate) fn remove(path: &Path, source: Error) -> Self

pub(crate) fn remove_and_defer( path: &Path, deferred_path: &Path, source: Error, ) -> Self

pub(crate) fn create_directory(path: &Path, source: Error) -> Self

pub(crate) fn create_extracted_file(path: &Path, source: Error) -> Self

pub(crate) fn archive_backend_unavailable(archive_kind: &'static str) -> Self

pub(crate) fn archive_backend_failed( archive_kind: &'static str, archive_path: &Path, backend_path: &Path, source: impl StdError + Send + Sync + 'static, ) -> Self

pub(crate) fn create_temp_file(path: &Path, source: Error) -> Self

pub(crate) fn write_temp_file(path: &Path, source: Error) -> Self

pub(crate) fn sync_temp_file(path: &Path, source: Error) -> Self

pub(crate) fn finalize_file( temp_path: &Path, final_path: &Path, source: Error, ) -> Self

pub(crate) fn open_zip_archive( zip_path: &Path, source: impl StdError + Send + Sync + 'static, ) -> Self

pub(crate) fn open_archive( archive_path: &Path, source: impl StdError + Send + Sync + 'static, ) -> Self

pub(crate) fn read_zip_entry( path: &Path, source: impl StdError + Send + Sync + 'static, ) -> Self

pub(crate) fn read_archive_entry( path: &Path, source: impl StdError + Send + Sync + 'static, ) -> Self

pub(crate) fn read_entry(path: &Path, source: Error) -> Self

pub(crate) fn write_entry(path: &Path, source: Error) -> Self

pub(crate) fn read_directory(path: &Path, source: Error) -> Self

pub(crate) fn read_directory_entry(path: &Path, source: Error) -> Self

pub(crate) fn copy_file( source_path: &Path, target_path: &Path, source: Error, ) -> Self

pub(crate) fn invalid_zip_entry_path() -> Self

pub(crate) fn invalid_archive_entry_path() -> Self

pub(crate) fn symlink_entry(path: &Path) -> Self

pub(crate) fn suspicious_compression_ratio( path: &Path, uncompressed_size: u64, compressed_size: u64, max_ratio: u64, ) -> Self

pub(crate) fn quota_exceeded( max_total_size: u64, current_total_size: u64, entry_size: u64, ) -> Self

pub(crate) fn path_too_deep(path: &Path, depth: usize, max_depth: usize) -> Self

pub(crate) fn file_count_exceeded( max_file_count: usize, current_file_count: usize, ) -> Self

pub(crate) fn reparse_point(path: &Path) -> Self

pub(crate) fn path_not_directory(path: &Path) -> Self

pub(crate) fn hardlinked_target(path: &Path) -> Self

pub(crate) fn copy_across_volumes( source_dir: &Path, target_dir: &Path, source: impl StdError + Send + Sync + 'static, ) -> Self

pub(crate) fn move_into_place( source_dir: &Path, target_dir: &Path, source: Error, ) -> Self

pub(crate) fn move_aside( target_dir: &Path, backup_dir: &Path, source: Error, ) -> Self

pub(crate) fn rollback_failed( action: &'static str, source_dir: &Path, target_dir: &Path, source: impl StdError + Send + Sync + 'static, rollback_error: impl StdError + Send + Sync + 'static, ) -> Self

pub(crate) fn unsupported_entry(source_path: &Path) -> Self